@@ -47,11 +47,11 @@ class DataServiceApplier:
     if exists:
       glog.info(f"Update DataService: {data_service.id}")
       if not dry_run:
-        self.client.update_data_service(data_service.id, data_service.to_proto())
+        _tracked_call(self.client.update_data_service, data_service.id, data_service.to_proto())
     else:
       if not dry_run:
         glog.info(f"Create DataService: {data_service.id}")
-        self.client.create_data_service(data_service.to_proto())
+        _tracked_call(self.client.create_data_service, data_service.to_proto())
 
     if data_service.credentials is not None:
       for i, cred in enumerate(data_service.credentials):
@@ -460,45 +460,51 @@ class ComponentApplier:
 
   def _create_component(self, data_service_id, dataflow_id, component: Component):
     proto = component.to_proto(self.id_map)
+    api_method = None
     if isinstance(component, ReadConnector):
       glog.info(f"Create ReadConnector: (ds={data_service_id} df={dataflow_id} {component.id})")
       if not self.dry_run:
-        return self.client.create_read_connector(data_service_id, dataflow_id, proto).data
+        api_method = self.client.create_read_connector
       else:
         return api_pb2.ReadConnector()
     elif isinstance(component, WriteConnector):
       glog.info(f"Create WriteConnector: (ds={data_service_id} df={dataflow_id} {component.id})")
       if not self.dry_run:
-        return self.client.create_write_connector(data_service_id, dataflow_id, proto).data
+        api_method = self.client.create_write_connector
       else:
         return api_pb2.WriteConnector()
     elif isinstance(component, Transform):
       glog.info(f"Create Transform: (ds={data_service_id} df={dataflow_id} {component.id})")
       if not self.dry_run:
-        return self.client.create_transform(data_service_id, dataflow_id, proto).data
+        api_method = self.client.create_transform
       else:
         return api_pb2.Transform()
+    if api_method is not None:
+      return _tracked_call(api_method, data_service_id, dataflow_id, proto).data
 
   def _update_component(self, data_service_id, dataflow_id, component: Component):
     proto = component.to_proto(self.id_map)
+    api_method = None
     if isinstance(component, ReadConnector):
       glog.info(f"Update ReadConnector: (ds={data_service_id} df={dataflow_id} {component.id})")
       if not self.dry_run:
-        return self.client.update_read_connector(data_service_id, dataflow_id, component.id, proto).data
+        api_method = self.client.update_read_connector
       else:
         return api_pb2.ReadConnector()
     elif isinstance(component, WriteConnector):
       glog.info(f"Update WriteConnector: (ds={data_service_id} df={dataflow_id} {component.id})")
       if not self.dry_run:
-        return self.client.update_write_connector(data_service_id, dataflow_id, component.id, proto).data
+        api_method = self.client.update_write_connector
       else:
         return api_pb2.WriteConnector()
     elif isinstance(component, Transform):
       glog.info(f"Update Transform: (ds={data_service_id} df={dataflow_id} {component.id})")
       if not self.dry_run:
-        return self.client.update_transform(data_service_id, dataflow_id, component.id, proto).data
+        api_method = self.client.update_transform
       else:
         return api_pb2.Transform()
+    if api_method is not None:
+      return _tracked_call(api_method, data_service_id, dataflow_id, component.id, proto).data
 
   def apply(self, data_service_id, dataflow_id, component: Component):
     """
@@ -539,3 +545,12 @@ def _component_id_to_uuid_map(client: Client, data_service_id: str, dataflow_id:
     id_map[c.id] = ComponentUuidType(type=c.type, uuid=c.uuid)
 
   return id_map
+
+
+def _tracked_call(method, *args, **kwargs):
+  '''call method, logging arguments if it throws an exception'''
+  try:
+    return method(*args, **kwargs)
+  except Exception as e:
+    glog.warn(f'{method.__name__} call failed, (args={args}, kwargs={kwargs}): {e}')
+    raise e
