@@ -281,9 +281,16 @@ def _classname_map() -> dict:
 def _inline_code_list_for(component: Component, resource_path_prefix: str, base_path: str) -> Optional[List[InlineCode]]:
   if isinstance(component, Transform) and component.operator:
     if component.operator.HasField("spark_function") and component.operator.spark_function.executable.code.source.HasField("inline"):
+      if component.operator.spark_function.executable.code.language.HasField("sql"):
+        resource_name = f"{component.id}.sql"
+      elif component.operator.spark_function.executable.code.language.HasField("python"):
+        resource_name = f"{component.id}.py"
+      else:
+        l = component.operator.spark_function.executable.code.language.WhichOneof("language")
+        raise ValueError(f"code download for language type \"{l}\" is unsupported")
       return [
           InlineCode(code=component.operator.spark_function.executable.code.source.inline,
-                     resource_path=os.path.join(resource_path_prefix, f"{component.id}.py"),
+                     resource_path=os.path.join(resource_path_prefix, resource_name),
                      base_path=base_path,
                      attribute_path=("operator", "spark_function", "executable", "code", "source", "inline"))
       ]
@@ -366,7 +373,7 @@ def _render_value(val, attribute_path: Tuple[str, ...], indent=0, classname_map:
   elif isinstance(val, Definition):
     return _render_definition(val, attribute_path, indent, classname_map, attribute_overrides)
   elif isinstance(val, str):
-    return f"r'''{val}'''"
+    return repr(val)
   else:
     return val
 
@@ -412,7 +419,7 @@ def _render_message(message: ProtoMessage, attribute_path: Tuple[str, ...], inde
     elif field_descriptor.type == descriptor.FieldDescriptor.TYPE_MESSAGE:
       return _render_message(val, attribute_path, indent, classname_map, attribute_overrides)
     elif field_descriptor.type == descriptor.FieldDescriptor.TYPE_STRING:
-      return f"r'''{val}'''"
+      return repr(val)
     else:
       return val
 
